Afrikaans
Akan
Albanian
Amharic
Armenian
Azerbaijani
Basque
Belarusian
Bemba
Bengali
Bihari
Bosnian
Breton
Bulgarian
Cambodian
Catalan
Cebuano
Cherokee
Chichewa
Chinese (Simplified)
Chinese (Traditional)
Corsican
Croatian
Czech
Danish
English
Esperanto
Estonian
Ewe
Faroese
Filipino
Finnish
French
Frisian
Ga
Galician
Georgian
German
Greek
Guarani
Gujarati
Haitian Creole
Hausa
Hawaiian
Hebrew
Hindi
Hmong
Hungarian
Icelandic
Igbo
Indonesian
Interlingua
Irish
Italian
Japanese
Javanese
Kannada
Kazakh
Kinyarwanda
Kirundi
Kongo
Korean
Krio (Sierra Leone)
Kurdish
Kurdish (Soranî)
Kyrgyz
Laothian
Latin
Latvian
Lingala
Lithuanian
Lozi
Luganda
Luo
Luxembourgish
Macedonian
Malagasy
Malay
Malayalam
Maltese
Maori
Marathi
Mauritian Creole
Moldavian
Mongolian
Myanmar (Burmese)
Montenegrin
Nepali
Nigerian Pidgin
Northern Sotho
Norwegian
Norwegian (Nynorsk)
Occitan
Oriya
Oromo
Pashto
Persian
Polish
Portuguese (Brazil)
Portuguese (Portugal)
Punjabi
Quechua
Romanian
Romansh
Runyakitara
Russian
Samoan
Scots Gaelic
Serbian
Serbo-Croatian
Sesotho
Setswana
Seychellois Creole
Shona
Sindhi
Sinhalese
Slovak
Slovenian
Somali
Spanish
Spanish (Latin American)
Sundanese
Swahili
Swedish
Tajik
Tamil
Tatar
Telugu
Thai
Tigrinya
Tonga
Tshiluba
Tumbuka
Turkish
Turkmen
Twi
Uighur
Ukrainian
Urdu
Uzbek
Vietnamese
Welsh
Wolof
Xhosa
Yiddish
Yoruba
Zulu
Downloaded from YTS.MX
Official YIFY movies site: YTS.MX
-[cheery Christmas-themed score]
-REPORTER: Chloe Anderson, congratulations on
your latest book, Sally and the Christmas Angel.
It's been a big success across the country
and it certainly looks like there's going to be
a big turnout here this evening.
-I am incredibly grateful to everyone
that's picked up my book and enjoyed
Sally's Christmas adventures through the years.
-And this is the tenth book in the Sally series.
Can we expect another one next Christmas?
-I haven't quite decided yet.
-Rumor has it
that you're working on your first novel.
-It's definitely something I've been thinking about.
-You're known for children's books, though.
It's a pretty big change.
-Uh, I... I guess. [chuckles] I mean, it's
it's still writing, just longer.
-Well, whether it's children's books
or a novel, I'm sure that everyone here is very excited
to see what adventure you take us on next.
Any big Christmas plans?
-Yes. I'm heading to Noelleville.
I have family that just moved out there, so I scheduled it--
-Dad, come quick! -...stop on my tour.
I will be signing at the Noelleville bookstore
and then enjoying the rest of the Christmas holidays
with my family. -Dad!
-INTERVIEWER: Thanks again for taking the time
to come to our big bustling city.
-It's my pleasure. -Dad!
-What? What's wrong? -Why are you wet?
-A leaking pipe. Why are you screaming?
-Chloe Anderson. -[score ends]
-Who? -Chloe Anderson.
She was on TV. You know...
Her. -Oh. [chuckling] Right.
Coolio, kiddo. -[sighs] Come on, Dad.
I've only been talking about how awesome it is
that she's coming here for weeks now.
-Honey, you know I'm bad with names.
And, honestly, I don't want you to get too excited
'cause no one ever actually comes here.
She'll probably just cancel and I don't want you
to be disappointed. -She won't cancel.
She even mentioned us on TV. She said that
she's signing books at the Noelleville bookstore.
That's our bookstore. Isn't that awesome?
-She did? Huh. -[cheerful score]
-She's coming to see her family.
It all makes sense now.
You should have seen the display that the store had on TV.
This poster is all we have.
-Honey, the poster looks great. She'll love it.
-Balloons. Can we get balloons? [excited inhale]
-Yes, we can get balloons.
Now, can you help me with this leaking pipe?
I'm trying to save the encyclopedia collection.
I'm not sure the Z's are going to make it.
-Okay, coming.
-[score fades out]
-It makes me so happy to share these stories with you.
When I was a little girl,
my mom used to read me special books before bedtime
that made me fall in love with stories.
And now my sister reads them to her daughter.
So it is a privilege for me to be here today
reading to all of you. Now...
who's ready to hear my new book, Sally and the Christmas Angel?
-[cheering]
-[tender score]
In a warm, cozy home in a snow-covered valley,
lived a nice little girl whose first name was...
-Sally!
-She loved Christmas time when all her family was near.
They played games and told stories.
It was the best time of year.
But this Christmas felt different
because her grandma was gone. She was now up in Heaven.
Her mum said, "Life must go on."
So to cheer herself up, Sally went on a mission
to find bows and wrap gifts for their family tradition.
But instead what she found was something peculiar,
a very old present that looked unfamiliar.
And in that dusty old box to her wondrous surprise...
-...wondrous surprise, was a beautiful angel
with sparkling blue eyes.
Tucked in her wings was a handwritten letter.
Sally carefully freed it from the pretty white feather.
It said, "I'm an angel of Christmas,
a messenger of cheer." [chuckles]
"I bring notes up to Heaven for loved ones to hear.
So if there's someone you miss,
I can help you feel better.
Just whisper your thoughts, and I'll bring them a letter."
So Sally closed her eyes tight and thought for a second.
"Tell grandma I love her. Merry Christmas in Heaven."
Suddenly, Sally felt very light.
She was happy and cheery and hopeful and bright.
So she thanked the kind angel and went on her way,
knowing her dear loving grandma, hm,
would smile on Christmas Day.
Okay, time for bed now, honey.
-I love you, Mom. -[mom chuckles]
-I love you, too.
-All done your story?
-Yeah. Hm.
Now it's time to say your prayers with Daddy,
and then get some sleep. We have a lot
of unpacking to do tomorrow to help Grandpa move in.
-Will Auntie Chloe be here tomorrow?
-[whisper] I think so. Goodnight, sweetie.
-Goodnight, Mom.
-Okay, kiddo.
Ready? [chuckles]
In the name of the Father, the Son, and the Holy Spirit.
Our Father, who art in Heaven, hallowed be thy name.
-[keyboard clacking]
-[sighs] -[phone ringing]
-Hey, Trish. -Hey, Chloe.
-Just checking in. -The event went great.
Just packing up here. I'm going to leave
first thing in the morning, and I should be there before dinner.
-That's awesome. We can't wait to see you.
-Me, too.
Hey, how's Dad doing?
-Putting on a brave face, but [sighs]
first Christmas without Mom is tough.
I think him moving in with us will really help.
-I'm sure it will.
Is he all settled in? -Getting there.
Truck arrived yesterday. Lots of boxes.
-I'll be there to help soon. And I'm going stop and pick up
some of Dad's favorite cookies to cheer him up.
-Great idea. But only a few.
I'm trying to get him to watch his sugar.
-Around Christmas time? Good luck.
-Hey, how's the tour going? -Good.
My, uh, book hit the bestseller's list this week.
-Congrats. [soft gasp]
Mom would be so proud of you.
-Yeah.
-We're all so happy that you'll be here for Christmas, Chloe.
-Me, too. Give Dad, Jana,
and Jeffrey a big hug for me, and I'll see you tomorrow.
-Will do. Drive safe.
Bye. -Bye.
-[gentle inhale, exhale]
-[music fades out]
-[loud upbeat Christmas music]
-[Christmas music plays over speakers]
-[door chimes ring]
-Little help?
-Whoa. What is all this?
You doing Santa's shopping for him this year?
-You doing his decorating? -That's fair.
-It's for the toy drive. Mrs. Jenkins asked me to
pick up a few things.
-Oh, is she coming to the big event tonight?
-She wouldn't miss it. And
she handed out all those flyers that you gave to her.
-That's awesome. So, what do you think?
-Uh, it's very festive. Did you buy up
every red and green balloon in Noelleville?
-Too much?
-[whisper] It's perfect. -[both chuckle]
-I still have so much more work to do.
-How can I help? -Uh, you can help me finish
decorating that Christmas tree. -Not a problem.
-Then we gotta put up those signs.
-Okay. -Wrap the door prizes.
-Door prizes? -Oh, and can you get cookies?
-What time does she get here? -Seven.
-We better get to work.
[Jana's mom hums "Deck The Halls"]
-[stops humming] -[tender score begins]
-Careful with that, honey.
That was your grandmother's.
She used to put that angel on her tree
when she was a little girl.
-We used to put it on our tree when you were a little girl.
How quickly the years go by.
-She's beautiful.
She looks like the angel from Auntie Chloe's book.
-Aren't you smart? -Is she?
-She sure is.
-Wow. Do you think she really takes messages up to Heaven
like she does in the books?
-I believe all angels do.
Do you have a special message that you want to send to someone
for Christmas this year, Jana?
-I'd like to send one to Grandma.
-You can whisper it to the angel.
-Okay.
Merry Christmas, Grandma. I wish you were here
so we could wrap presents and dance to our favorite
Christmas songs like we did last year.
But I know you're in Heaven with God
and I just want you to know how much I love you.
-That was beautiful, honey.
-Can we put the angel on top of our tree this year?
-Ask your grandpa. It belongs to him.
-Grandpa, can we?
-I would love that. [EMOTIONAL BREATHS]
Now that I'm moving in,
maybe we could make it our tradition. Hm?
-I'm happy that you're moving in with us, Grandpa.
-Me too, sweetie.
-[phone rings] -Oh. Let me get that.
-[phone rings]
Hello?
-Hey, Trish. I just got into town. I am picking up some
gingerbread cookies for Dad. Be there in about ten minutes.
-Remember, just one cookie.
-Two. -One.
-Three? -Okay, two. [chuckles]
-Okay, deal. I'll see you in ten.
-Bye.
-Hey, uh, can I help you? -Yeah. Um, can I get--
-[phone rings] -Oh, um...
You can go ahead of me. I need to take this.
Hello?
-Chloe, did you read The New York Times?
Glowing review. Sales are through the roof.
-Heather, hi. Yeah, I did. -How's the tour going?
-Great. I am heading to my last book signing
in Noelleville tonight.
-Still don't know why you booked that one. What is there?
Ten people in that town? [laughs]
-Every place counts, Heather.
-Sure. I'm calling 'cause
I read the first few chapters of this novel you want to write.
-You did? -Yeah, it's good.
But, honey, you're known as a children's book author
and that's where our sales are. -It's not about sales, Heather.
-It's always about the sales, Chloe.
I just don't know if this is something that I can
get behind. Can you shelve this one
for another year and focus on what you do best?
-That's what you said last year. -Yes, and
look at the success of this book tour.
It's risky, honey. What if people don't like it?
-What if they do?
-Take the holidays to think about it.
And congratulations on the success of the book.
-Thanks, Heather. Bye.
[clears throat] Oh, no. Do you have any
gingerbread cookies left? -I'm sorry, sold out.
-But you had a tray full of them like a minute ago.
-Snooze, you lose?
-Can you check the back? They're my dad's
favorite cookies and I wanted to cheer him up.
-Everything we have is here, but, uh,
Christmas tree sugar cookies -- they are delish.
-I'm sorry to eavesdrop, um, but I think I can help you out.
I'm the guilty party that bought them all.
I got 36 here. Uh, how many do you need?
-Oh, um... I couldn't.
I mean, you snooze you lose, right?
-You gonna order anything, or can I take the next order?
-I'll get out of your way.
-I insist. You let me cut in line, so...
-Well, in that case, maybe just one.
It's for my dad. -I've tasted these cookies.
There's no chance he's only gonna want one.
-Two? -I'll tell you what:
Why don't you take this box of 12 right here.
-Really? That's so kind of you.
-Don't worry about it. Just pay it forward.
You know, I help you, you help someone else,
and we start a wave of kindness for the Christmas holidays.
-I like that. Okay, deal.
Um, thank you for the cookies and have fun at your party.
-Party? -Oh. I just assumed.
I mean, that is a lot of cookies for just one man.
-Oh, uh... [chuckles]
Well, like I said, you can't just eat one.
-[both laugh] No, I'm kidding.
It's, uh, they're for my daughter, Alex.
Not that she's gonna eat them all either.
She's planning this event tonight,
and she's hoping a lot of people show up, so...
Some big shot writer's coming into town
and, uh, signing books at our bookstore.
No one ever comes to Noelleville so it's kind of a big deal.
And you can come if you want. Everyone's invited.
I would tell you who it is, but, honestly,
I'm terrible with names. It's like, uh...
Kathy or Carrie or something.
-You own the Noelleville bookstore.
-Yeah. -I'm Chloe.
-Hey, Chloe. Ethan. Nice to meet you.
-It's nice to meet you, Ethan.
I will definitely be at your event tonight.
-You will? Oh, that's great.
Yeah, we put up a lot of flyers, but I wasn't sure
if anyone was gonna show up so it's nice to know
our little attempt at publicity worked.
I was kinda worried about that. -[chuckles]
-Now I just need this, uh,
Kathy person to show up.
You never know with these celebrity types, right? Whoo.
-[both chuckle] -Yeah, so unreliable.
-Yeah. Just don't want my daughter to be disappointed.
She worked really hard on this. She's super excited.
-I don't know about this Kathy person, but I'll be there.
-Great. Okay, well, we'll see you tonight.
-Great. Thank you for the cookies.
-You betcha.
["Joy To The World" plays as score]
-[doorbell rings] -I'll get it. [chuckles]
["Joy To The World" fades out]
["Good King Wenceslas" plays faintly]
-Hello?
-Chloe.
I am so happy to see you.
Dad's gonna be thrilled you're here. Come on.
-Guess who's here. -Auntie Chloe!
-CHLOE: Hey! [gasps]
Oh, my goodness, look how tall you got.
-[Chloe and Jana chuckle] Hey, Dad.
-Hey, sweetheart. -CHLOE: Oh.
-DAD [whisper]: Good to see you. -Guess what I brought you.
-[gasps] Gingerbread cookies! Yay!
-You always know how to make this old man happy.
-I missed you, Daddy. -I missed you too, sweetheart.
[Dad chuckles]
-Good to have you here, Chloe.
What time you need to head over to the book signing tonight?
-Couple of hours. I'd like to get there early to set up.
Are you guys coming?
-Of course we are. We're your biggest fans.
Now, hand over those cookies.
-Can the cookies wait 'til after dinner, Dad?
-Oh, I'm afraid not, sweetheart. It's the holidays. Right?
-JANA: Right. -[Dad and Jana chuckle]
-It's a losing battle with you guys.
Okay, hand me one, too.
[Christmas carol fades out]
-I love it. -You'll look
so beautiful tonight.
-That was so sweet of you to bring me a dress.
-Go try it on. I'll watch the store for a few minutes. Mm?
-Okay. -[both chuckle]
[doorbell chimes ring]
-Mrs. Jenkins. What are you doing here?
The event doesn't start for a few more hours.
-Well, I wanted to thank you
for all the shopping you did for the toy drive.
-Oh, please don't mention it. -And...
I wanted to bring a little something special for Alex.
It's her big day, so
I brought her a pretty Christmas dress. [chuckles]
Yeah, I'm watching the desk while she tries it on. Hm.
-A dress? Wow.
I haven't seen Alex in a dress since she was a little girl.
-It is her big day. She needs to feel special.
I know, I raised three daughters.
I remember that age.
-Thank you. Hm.
-[tender score]
-It's hard, you know, without Deb.
A girl her age needs a mom.
-Oh, you're a good dad, Ethan. You're doing okay.
-I-I know, I just... I just worry about her.
She's so quiet and she's always losing herself in books
rather than being on adventures of her own.
You know, when I was her age, you couldn't keep me at home.
-Hm. We all come out of our shells...
at different times. -Mm-hm.
-But look at all she put into this event. Ah.
-It is impressive. [chuckles] -Mmm.
-She's just so passionate about books and writing.
I wish I could give her the guidance that she needs,
but I'm just the guy that inherited an old bookstore.
What do I know about dreams?
-Oh, she'll find her way, Ethan.
-Yeah.
-And so will you.
-[score fades out]
-Well? -[sharp gasp]
-Wow. -Oh...
-What do you think?
-Honey...
You look--
so grown up.
-[whisper] Beautiful.
-Beautiful, sweetheart. You look beautiful.
-[tender score] -[sighs happily]
[squeaking]
-Need a hand with that?
-Uh, I think I finally got it.
It's a tricky little thing, though.
Oh, hi. It's you.
-Hi.
-Uh, Chloe, right?
-I thought you were bad with names.
-Normally I am, but for some reason, yours just stuck.
-I can't imagine why.
-Let me guess: Your last name's Anderson.
-You're good at this. -I was afraid of that.
Okay, well, this is embarrassing. [chuckles]
I am so sorry.
Uh, my daughter has been talking about you for weeks.
First big celebrity I meet and I come across as a big fool.
-I think you came across very kind.
You gave up a dozen delicious cookies
to help a complete stranger. I mean, that makes you
pretty awesome in my book.
And you can ease up on the celebrity bit.
I'm just a writer. Most people don't even recognize me.
-[laughs] Don't tell my daughter that.
She thinks you're a pretty big deal.
-It'll be our little secret.
-Well, you're a little early. No one's here yet.
-That's okay. It'll give me some time to set up.
-Okay, well, in that case, come on in.
-Great.
-[hinges squeak] -[doorbell chimes ring]
Wow, this looks awesome. Your daughter planned all this?
-She did. I helped a little. I did the tree.
Most of it. Some of it.
-[laughs] Nice.
Is she here? I'd love to meet her.
-She should be. Alex?
It's weird. She was here a minute ago.
Alex!
-Dad, come quick! Pipe. Basement.
This is a disaster. Everyone's gonna be here soon!
-I'm sorry. Make yourself at home. Uh, I'll be right back.
-Okay, yeah, no problem. -Help yourself. Cookies, coffee.
There's everything, okay?
-Come on everyone, time to go! We don't wanna be late!
-Where's Aunt Chloe? -She went over early to set up.
We're gonna meet her there. Now where are your shoes?
-I don't know! -Can you help find her shoes?
-JEFFREY: Mm-hm. -Dad, you coming?
-Sorry for holding things up.
I just can't seem to get this tie on properly.
-I didn't mean to rush you, Dad. Come here.
Let me help you with that.
-Your mother's been helping me fix my ties for the last
[deep inhale] 50 years.
-GRANDPA: Hm. -[somber score]
-You look very handsome.
-Thank you, sweetheart. -JEFFREY: Found 'em!
Whoa-whoa-whoa-whoa. Jacket, kiddo.
Okay, everyone, let's get going.
-You look great, Grandpa! -Thanks, Jana.
-[score fades out]
-This night is a disaster. It can't get any worse.
-I'm sorry about your dress, sweetheart.
-What am I gonna do? I don't have enough time
to go home and get cleaned up before I meet...
Chloe Anderson?
-Uh, I'm sorry, I meant to tell you that she was here.
-Okay, I was wrong. This night just got worse.
-Is everything okay? -It's under control.
It's the pipes in the basement.
-Well, you did a beautiful job with the store, Alex.
-Thank you. It's such an honor to meet you, Miss Anderson.
-Oh, call me Chloe. -Chloe, right.
Wow, I can't believe you're actually here.
I'm sorry, I didn't want to look like a disaster
when I first met you. -What are you talking about?
You look beautiful. -My dress is stained.
-Well, it's nothing we can't fix in a couple of minutes.
Do you have any soda water? -It's in the fridge.
-Lead the way.
-Thank you for helping me.
-Well, thank you for making the store so festive.
It is the prettiest store I've seen on this tour.
-[tender score] -I can tell how
much thought and care you put into it.
-I just wanted to make it perfect for you.
My mom used to read to me those books that you wrote
when I was a little girl. -That's so sweet.
I would love to meet her.
-She passed away five years ago.
It's just me and my dad now.
-Oh. I'm sorry.
I just lost my mom too.
-It's a hard thing, isn't it?
-It sure is.
-It gets better with time.
[fabric rustling]
-So have you always lived in Noelleville?
-We moved here when I was a little girl.
My mom inherited the bookstore from her aunt and
wanted to run it, so we packed up and moved here.
When my mom passed away my dad wanted to move,
but he saw how much I loved the bookstore
and decided to stay.
-He sounds like a good dad.
-He's the best.
You know, I love books.
I want to be an author, too, when I get older.
-What kind of books do you want to write?
-Adventure novels. -Good for you.
-I just, I don't know where to start, you know?
-Well, I'm in town for the holidays.
How about we set up some time to go grab
some hot chocolate and chat? -[score fades out]
I can give you a couple of tips on how to get started.
-Really? -Absolutely.
And look: Stain's all gone. Good as new.
-Thank you, Chloe. -You're welcome.
Do you want to head back in? -Let's do it.
-Okay.
[Christmas music plays over sound system]
Merry Christmas.
-[chuckling] Oh. I'm Jean Jenkins.
This is my gal pal, Rosie.
-Hi. -Hi.
-We're so thrilled you're here.
A little elf told us you might
be staying in Noelleville over the holidays.
-That's the plan. -JEAN: Oh!
Well, we wanted to give you
a little welcoming gift from our church group.
-[Chloe gasps lightly] -[Jean laughs]
It's slippers.
Noelleville can get very cold this time of year
so we wanted to make sure you got a warm welcome.
[chuckles] -It is so thoughtful.
Thank you, I love them.
-Our pleasure, dear. Oh...
Would you please make it out to my granddaughter, Freya?
-Absolutely. -It's F-R-E-Y-A.
-She's come a long way since selling her homemade books
at our annual yard sales, hasn't she?
-Mm-hm. I'm so proud of both my girls.
-Oh. -Mm-hm.
-[tender score] -[Mrs. Jenkins laughs]
-Thanks so much for coming tonight.
This night meant a lot to Alex.
-It was my pleasure. She's a sweet kid.
-Yeah, she is.
So, how long are you in town for?
-Couple of weeks. I'm gonna spend the holidays
with my family.
-Well, I hope to see you around. -[chuckles] You will.
I have a date with your daughter.
-You do? -Yeah.
Turns out she wants to be a writer, so I offered
to give her a little bit of guidance.
-It's really nice of you.
-Well, a kind guy did something nice for me today,
so I'm just paying it forward.
Starting a wave of kindness, I think he called it.
-[chuckles] -Hey, we're gonna head out.
Get Jana to bed.
You coming? -I'll be right behind you.
Well, it was nice to meet you, Ethan.
-It was really nice to meet you, Chloe Anderson.
-You're getting better with names.
-Well, like I said, this one just sticks.
-Goodnight, Chloe. -Goodnight.
-Can't wait for our hot chocolate date.
-[gasps] Me too.
[doorbell chimes ring]
-Isn't she amazing?
-Yeah, she's okay, I guess.
-She's amazing.
-[laughs]
-[Christmas song as score]
♪ I'm counting down the days
♪ Christmas time is here again Everybody's coming to town ♪
♪ Santa I've got someone special ♪
♪ A lot to figure out I'm hoping you can help me out ♪
♪ You want it wrapped [unclear]
♪ Love brought me some [unclear] ♪
♪ I can see I'll be At the top of your list ♪
♪ Every year after this
-Did you sleep okay? -Like a log.
So, what's on tap for today?
I can move boxes, set up furniture.
You name it, I will do it. -How about we start
with a healthy breakfast?
Jeffrey's making us omelets downstairs.
-Ooh, I like that plan. -[Trish laughs]
-And then, do you think that you could take Dad and Jana
to pick out a Christmas tree?
I have to teach a yoga class and Jeffrey needs to get to work.
The move and everything, we're a little late
on getting a tree this year
and I don't think Jana can wait another day.
-Of course. I would love to.
-Thank you.
This the novel you've been working on?
-Yep.
-I'm happy you're finally moving forward with it.
-Mm. I don't know that I am.
My publisher's still not thrilled about the whole thing
and she thinks that I should "stick to what I'm good at."
-So, find another publisher.
-It's not that easy, Trish.
-It can't be that hard.
You're Chloe Anderson.
-[upbeat folk guitar score]
-[grunts]
-How many more trees do we need?
-Mrs. Jenkins wants as many as we can gather.
Oh.
She wants the church to look beautiful.
-That seems like a lot of decorating.
We may need to recruit some help.
-Yeah, tell me about it. Oh.
-Oh, fancy meeting you two here.
-Chloe, hi. -Hi.
-Are you guys picking up your Christmas tree?
-Yes, we wanna find the biggest,
tallest, best tree ever this year.
-Did you leave any trees for the rest of us
or is this a gingerbread cookie kind of situation?
-We left some trees, but we did try to pick the best ones.
It's for the church. -Oh, that's nice.
-They have the most beautiful Midnight Mass ever.
You guys should come. -Well, sounds lovely.
-Any chance you wanna help decorate Christmas trees?
-I love decorating trees.
-It sounds fun. What about you, Dad?
-Why not? Count me in.
-Great. Maybe we can do our hot chocolate date tomorrow
and then we can go to the church.
-I'll run it by Trish but her and Jeffrey
are working this week, so I don't see why not.
-Can we go see Santa?
-Sure thing. -I can bring her.
-Okay, thanks. -Alex, do you wanna come?
-Dad, can I go?
-Um, sure.
And here I thought Alex was too old for Santa this year.
-You can never be too old for Santa.
-[chuckles] So, are you all settled in?
-I travel light. You know, pen, paper and warm, cozy socks.
The necessities of any writer.
-Alex told me about your mom. My condolences.
-Yeah, it's been a difficult year for us,
but being together for the holidays is nice.
-It was really nice meeting
your entire family at the book signing.
-And what a turnout. -Yes. We needed that.
-Does the bookstore do okay? -[quiet score]
-It's a small town. There's really not that much
business here. Most people just read their books on tablets
so we're a bit of a dinosaur that way.
-Things really have changed, haven't they?
It's a shame.
I love books.
How they feel in your hands, turning the pages.
Tablets just aren't the same.
-I wish more people felt that way.
-Auntie Chloe, do you wanna go take a photo with Santa?
-[excited gasp] Absolutely.
-Are you coming, Ethan? -Me too?
-You can never be too old for Santa.
-I would love to. -[Jana and Chloe laugh]
-[Ethan, imitating Santa] Oh, ho, ho, ho, ho, ho!
[slow instrumental "O Tanenbaum"]
-Cute Santa photo. How exactly did this come about?
-We ran into him at the tree farm.
-Interesting.
See, I run into acquaintances all the time,
and I don't take family photos with him.
-Stop it. -What? I'm just saying
he seems nice. -[Chloe sighs softly]
-And you guys seem to click.
-He is nice. -And...?
-And maybe we click a little. -[Trish chuckles]
-Can I have the Santa ornament?
-[Jana, whisper] Here you go.
That sounds promising.
-Stop it. I live far away and he's just a nice guy.
Plus, you know me, I don't have time for that kind of stuff.
What? I have tight deadlines.
-You have thick walls is what you have.
-[soft sigh] That's fair. -[Jana chuckles]
I think that you need to take a little break
from all those deadlines.
And you need to bring a few of those walls down.
Live a little, Chloe.
Are you gonna see him again?
-We promised to help him decorate
the Christmas trees at church.
-And he volunteers to help the church.
-[Chloe laughs quietly] -Ha! Hm-hm-hm. [laughs]
-How does it look, Mom?
-It's beautiful, Jana.
-I think it's time to put the angel up.
What do you think? -Yes.
I gave the angel a special message for Grandma.
-Oh, that's so sweet.
She will be so happy to get it. -[Jana laughs quietly]
-You ready, kiddo? -I'm ready.
-[touching score]
-My mom used to read me these incredible stories
before bedtime.
They transported me to other worlds and made me
fall in love with writing. -[score fades out]
She was really good at making me follow my dreams.
She even helped me publish my first book when I was 12.
-Twelve? -Yeah.
It was a ten-page homemade book.
We even started our own publishing company
called Angel Wish Publishing.
And we gave them out as presents for Christmas
and sold the rest at a yard sale that summer.
-I love that. [laughs] -And as I got older,
I just kept writing.
Y'know, eventually, I submitted to every publisher in the city.
And this one small publisher actually agreed to meet with me.
And after several more submissions, she finally agreed
to publish my first book, A Time for Christmas.
-I don't think I've ever heard of that one.
I thought I had all your books. -It's a hard one to find.
It had a very limited release and it didn't do too well.
But I just kept writing.
And eventually my writing caught the eye of a big publisher
and that's when my career really took off.
So why do you want to be a writer?
-I guess I love getting lost in stories.
And I want to be able to write my own characters and...
have adventures through their eyes.
I've written a lot of short stories.
I just don't know what to do with them.
-Well, I'd be happy to read them sometime.
I mean once I have a better idea of where you're at,
maybe we can come up with an action plan for your next steps.
-That would be amazing.
-All right. Deal.
["Oh Come All Ye Faithful"]
♪ Oh come all ye faithful
♪ Joyful and triumphant
-Can I ask you something?
-Sure, but only one thing. -[both chuckle]
-Do you help everyone you meet?
It's like every time I see you, you're doing something nice
for someone. -You caught me on a good week.
-I doubt that. -[chuckles]
'Tis the season, right?
-I guess. [laughs]
-Now it's my turn to ask a question.
-Okay, shoot.
-What does a big shot writer do in her downtime
when she's not touring or visiting family?
-That's a good question. Um, I mostly write,
watch terrible reality shows. -[Ethan laughs]
-And, um...
Try to keep my mind busy these days.
-You know he's going to be fine, right?
He's got a great family. He has lots of support.
-I know. It's just hard not to be here to help.
My mom was his whole world, you know?
-Oh, I can relate.
-How did you do it? After Deb?
-Well, it takes time to heal, but eventually,
you start finding joy in the little things again.
Had all these big plans for a big life, and...
Life changes. You can't stop it.
Worrying about it doesn't change the outcome, so...
what's the point?
-It's a great way to look at life.
Don't you ever worry about the future?
-Oh, I can't think that far ahead.
I take it one year at a time, sometimes one day at a time.
Pipe bursts, I fix the pipe.
Alex, uh, needs help with her math homework, I help her out.
We're short on sales one month?
Uh, I tile Mr. Jones' bathroom floors.
-The church needs Christmas trees
and you offer to decorate them.
-Something like that. -[Chloe chuckles]
-Sometimes it feels like there's not enough hours in the day.
Or money in the bank.
But somehow, some way, we make it work.
-You should try selling your books online.
I mean, you have a great collection.
If you open up your sales to a worldwide audience,
imagine the potential growth.
-Hm. I wouldn't even know where to start.
-It's a lot easier than you think.
I can teach you in an afternoon and we can take it
one hour at a time.
-Okay, I'd like that.
-Auntie Chloe, look at our tree.
-Wow. It's perfect. [tender laugh]
-It's almost perfect. Wait one second.
-It's beautiful, Jana.
-I paid attention when you read your book,
and I thought it would be nice for each of us
to have our own angel, put 'em on top of the tree
and send them with a special message.
Come on, everyone. Grab an angel.
-Is there a special way to do this?
-I'll ask the expert.
-Well, you whisper a message that you want sent to Heaven
for Christmas, and you put your angel up on the tree.
She'll make sure that it gets there.
-MRS. JENKINS: Oh. -Okay. Let's go.
[Christmas carols play softly]
-Having a hard time finding the words?
-A little. -I had a hard time, too,
the first Christmas without my mom.
-You were young.
I'm old enough that I should be able to accept things,
but the truth is that she left so fast
I didn't get a chance to say goodbye.
And I am embarrassed to say that...
been a little distant ever since.
-It's okay.
I gave God the silent treatment, too,
after my mom passed away.
My dad said that's okay.
God can take it.
And when you're ready,
He'll be there.
Losing family is hard,
no matter how old you are.
-You're a special young woman, you know that?
-And remember, there's no rush in sending a message.
There's still time before Christmas.
-Yeah.
-Why don't I help you put this up?
-Okay.
[tender score]
It's the last of the boxes.
-[Dad sighs quietly] All moved in.
-[soft gasp] This what I think it is?
-[laughs] Your very first book.
-You kept it. -Of course I did.
[laughing]
Oh...
-I remember how excited I was when Mom and I officially named
our first home publishing company.
-Angel Wish Publishing. Huh.
I was so proud of you. Huh.
-Mom really was good at pushing us
towards our dreams, wasn't she? -Oh...
She was the dreamer. [chuckles]
I was the plumber. -Mm.
-We made a good team.
I wonder if this still fits. -[both laugh]
-CHLOE: Aw. -Oh.
-So many memories in one small box.
-Oh, wonderful memories.
-[tender whisper] Yeah.
-You know, honey, your mom always knew
you were going to make it. She had this way
of looking at life that was an inspiration
to everybody around her.
-What do you think Mom would say about
me taking a chance and writing my first novel?
-I think you know exactly what she would say.
-Even if it's risky? -Follow your heart.
Don't worry about what other people think.
And if your heart is telling you to write a novel,
I think you should do it.
-I wish that I was as brave now as I was back then.
Why does it get so much harder
to take risks when you get older?
-Well, honey, when we're young, we got nothing to lose.
So we jump all in and start building a life.
And if we're lucky, we build a good one.
But as we get older, we get more cautious
and we don't want to risk any of it.
We just want to hang on to what we have.
The truth is...
we can't really hang on to anything in this life.
Best we can do is to enjoy the moments
and follow our hearts.
-How did you get so wise?
-[chuckles] I traded my youth for wisdom.
-[both laugh] -[score fades out]
-[doorbell chimes ring] -Good morning, Ethan.
-Hey, Mrs. J. How are you doing?
-Good.
Don't often see your nose in the computer.
What are you so focused on?
-Did you know that these big chain bookstores
sell books online to anyone in the world?
-Of course. -It's amazing.
No wonder they thrive. -Uh, yes, dear. Uh...
You have heard of the internet, haven't you?
-Yeah, yeah. Yes. -[both laughing]
-Oh, the world keeps getting smaller, Ethan.
We're all connected.
I order my yarn online one day, and the next day,
it's right there at my door.
Books are no different.
-Maybe Chloe's right. An online store
would be really good for us.
-Chloe's helping you with the online store?
That's exciting.
-Yeah. A little overwhelming, too.
-Oh, that's nice to see you two getting on so well together.
And it's great for Alex to have a fellow writer to talk to.
-Yeah, they really hit it off.
-My Spidey senses are telling me
that Alex isn't the only one hitting it off with Chloe.
-[laughs] Well, she's nice.
-And beautiful.
-Yeah. And smart.
-And, uh...
single.
-No. Yes... But, uh, no, it's not like that.
-And why not?
Ethan Carter.
When a beautiful, kind woman walks into your life,
don't ignore it.
-Yeah, she's pretty incredible.
But I can't. Uh,
I just don't have time for anything like that.
I-I got to look after Alex. I have to look after the store.
-Oh, honey.
It's also important to look after yourself.
-Hm. -Alex isn't a little girl
anymore and she just wants to see you happy.
-[tender score] -[whisper] Yeah.
-Anyhoodle...
I came in to ask you a little bit of a favor.
My daughter was at a charity auction last week
and she won two tickets
for a private ballroom dance lesson.
She can't go, [zipper] so she offered the tickets to me.
Oh, I think it would be a hoot.
But I don't have a date.
I know it's short notice, but would you be willing to
take this old gal dancing? Hm?
-[Ethan chuckles softly]
-Do I need rhythm? -Oh, it wouldn't hurt.
But I'm tight on time and short on options.
-Well, in that case, how can I say no?
-Oh, good.
See you at 8 p.m.
Wear your best suit.
-[soft gasp] Ah...
So cute. She's going to love that.
-[phone rings] -Good.
-One sec.
Hello.
Yeah, she's right here.
[whisper] It's for you. It's Mrs. Jenkins.
[score fades out]
-CHLOE: Hello. -Oh!
-Chloe? -Jean?
-Hi, honey. Oh.
I hope you don't mind me reaching out like this.
-Of course not. -How are you doing?
-I am doing great. I am just spending the day with Trish
and we are wrapping presents.
-Oh. How are those slippers?
-Cozy. I am wearing them right now.
-I know it's a bit of short notice, but
I have a bit of a favor to ask.
-Sure. What's up? -I have two tickets
for a private ballroom dancing lesson for tonight.
My daughter won them at a charity event.
I promised to go with Ethan, but oh,
my darn hip is acting up again.
[sucks teeth; gasps softly] Anyway, Ethan was
so excited, I don't want to disappoint him.
Would you do me a huge favor and go in my place tonight?
-You want me to go ballroom dancing with Ethan.
Tonight?
-What?
-[splutters] For me.
-For you. -Oh!
And the charity, of course.
-Jean, why does it feel like I'm being set up?
Does Ethan know about this?
-About the dancing lessons? Well, of course.
I told you I told him first.
-Okay, I will be there.
-[soft gasps] Oh, perfect.
Thank you so much, honey. Eh, it starts at eight.
Dress code is formal.
-Okay, bye.
I may need to borrow a dress.
-Yes!
[Trish giggles happily]
-You are not who I expected.
-I kind of figured.
-Where's Mrs. Jenkins?
-Probably at home patting herself on the back
for pulling this off.
-Wow, you look absolutely beautiful.
-Oh, um, thanks.
It's Trish's. I forgot to pack my gown.
Ballroom dancing wasn't exactly on my itinerary.
-I remember. You pack light.
-[laughs]
I have to warn you:
I have two left feet, no rhythm, and there's an 87% chance
I step on your foot.
-Thirteen's my lucky number.
-Is that a math joke? -I think it is, yeah.
[both laugh]
-Um, this place is gorgeous.
-It's pretty stunning, yeah.
-Hi, I'm Marilyn.
-Hi, Marilyn. I'm Ethan.
This is Chloe. -Hi.
-Welcome to your private ballroom dance lesson.
Should we get started?
-Sure. [chuckles] -MARILYN: Yeah.
Okay, so the most important thing in ballroom dancing
is the connection between you and your partner.
Now, you want to face each other.
Make sure to keep eye contact.
Now, you want to put your hand in the small of her back
and pull her close, like this.
-Is that okay? -Yeah.
-Now we just need some music.
[score fades out]
♪ It's been a long, hard year
♪ There's no doubt about it ♪
♪ So let's lay it down
♪ And rest for a while
♪ Feels like we lost our cheer
♪ Can't go on without it
♪ But it's all around
♪ It's in every smile
♪ And just as the snow starts to fall ♪
♪ Let's listen in close to the night ♪
♪ For all of our voices so bright ♪
♪ Sing your joy
♪ And I'll sing my joy
♪ And wherever you're singing ♪
♪ We'll send it up ringing tonight ♪
♪ When you glimpse the hope
♪ Try to hold on with that sacred spark ♪
♪ And that's when
-That was fun.
-And you didn't even step on my feet.
-I guess 13 is your lucky number.
-[Ethan laughs] I'm glad I came.
I usually don't venture out and do stuff like this on my own.
-Think it's harder to take risks and do things like this
as we get older, doesn't it? -[tender score]
I mean, I remember being fearless as a kid.
What happened to that girl?
-You still seem pretty fearless to me.
-Well, I guess I have you fooled.
Literal buckets of fear. [chuckles]
-Do tell, Chloe Anderson. What are you so afraid of?
-Mostly, um, snakes and alligators.
I don't trust reptiles. I think it's their eyes.
-Totally legit. -[Chloe laughs]
-But also some life stuff.
I guess lately I've been worried about my career.
-Your career?
You're a bestselling author and you just finished
an incredibly successful book tour.
What could you possibly be worried about?
-You know when you just feel like you're not on
the right path anymore?
Make a change.
I want to write a novel.
-So write a novel.
-Yeah, I mean that's what my heart says, but...
my publisher isn't thrilled about the idea.
And, honestly, I don't know if I could do it
without her backing me.
-You don't seem like the type of person
that needs permission to do something that she loves.
-At some point, I guess I didn't.
-And now?
-Buckets of fear.
-[both laugh]
I mean, if I go against my publisher,
what if she stops repping me?
If I write the novel, what if it fails?
And then if I go back to children's books,
what if my audience has moved on?
-That's a lot of what-ifs. -Hm.
-Is that why you're still single?
-[scoffs] Excuse me?
-I just mean that you're beautiful,
you're funny, you're smart,
you're talen-- -Complicated?
-We're all complicated. -[Chloe chuckles]
-I think that relationships are just tough for me.
I'm always lost in my thoughts.
Sometimes I'm in the past, sometimes I'm in the future.
And as a writer, I'm observing everything around me
all the time. People, places...
And that can make it very difficult
to connect with what's right in front of me.
I don't know...
I guess the mind of a writer is a difficult thing
to understand or get used to.
But when you're constantly coming up with
infinite possibilities and potential outcomes,
it makes it easy to get scared and to run away
from a relationship before it even gets started.
-I understand more than you think.
I have an aspiring young writer in Alex,
wise beyond her years, but she's often lost
in books and in thought.
But she has this...
Mm, unbridled joy for the present.
She sees the world in ways and colors that
truly amaze me.
Just because a person isn't the easiest to get close to
doesn't mean that it's not worth trying.
That being said,
would you like to go to dinner with me on Monday night?
-Oh. - I'll cook.
[both laugh]
-I would love to.
-It's a date.
-It's a date.
Um, I was wondering if I could bring my dad over.
-On our date?
-Oh, um... -[tender score]
No, different thought. Um, Saturday.
If you guys are around. He's a plumber.
-Oh. -Anderson Plumbing. The best!
-[Chloe chuckles] -Whoa. [chuckles]
-Maybe he could help you out with that pipe.
And at the same time, I could help you open that online store?
-Okay. I-I-I'd love that. Um... we're free Saturday afternoon.
-Okay. Saturday afternoon.
She's pretty good.
[score fades out]
-So, how was it? [gasps dramatically]
Did you have fun? Did he love your dress?
[laptop clatters onto table]
Chloe! It was my bedtime two hours ago
and I have to teach Christmas yoga in the morning.
You better stop playing and start giving me all the details.
-Did you wait up for me? -Yeah, of course I did.
Now dish.
-Okay, okay, um, it was... [exhales]
Amazing.
-I'm gonna need you to be more specific.
-It was really, really fun.
He looked amazing in his tux, and he was sweet
and kind and funny.
And we danced until I thought my feet were gonna fall off.
-Please tell me you kept your shoes on.
-Only because it was a first date.
-So it was a date! -I don't know.
I mean... [sighs]
Maybe. [sighs]
But he did ask me out again.
He's gonna cook for me on Monday night.
-So, he's kind... -Mm-hm.
-Funny... -Mm-hm.
-And he cooks?
-Apparently. -[Trish sighs]
Wow! [gasps, sighs] -[Chloe giggles]
-[tender score] -I miss this.
-Me too.
Reminds me of old times.
I really wish you could stay.
-You know I can't.
-Why not?
-Um, because...
I don't live here. -Mm.
-And I have a life I need to get back to.
-But you could. [sighs] Especially if you plan on
writing a novel. I mean, what better place
to be creative than surrounded by people that love you?
-I haven't even decided if I'm gonna write it yet.
-Haven't you?
I'm just saying, [deep inhale]
I haven't seen you smile like this in a really long time.
Maybe spending a little more time with us,
wouldn't be the worst thing in the world.
Well, I gotta catch some Z's because this
family Christmas yoga will not teach itself.
-Family Christmas yoga? -8 a.m. sharp!
And before you ask, yes, it is mandatory.
-You're gonna make Dad do yoga? -Mark my words, by Easter,
that man will be doing a downward dog
like no other 70-year-old around.
-[laughs]
-Goodnight, Chloe. -Goodnight, Trish.
-Love you. -Love you.
Hi, Heather. It's, uh, Chloe.
Look, I know it's Friday night and it's late,
but I just wanted to call you and tell you that I...
I decided to write my novel.
I'm gonna focus on that this year and I really,
really hope that you support me.
Anyway, um...
just give me a call on Monday when you get a chance.
Bye.
[score fades out]
[upbeat acoustic guitar]
♪ Home, home, home
♪ Holidays at home
♪ Nothing like holidays at home ♪
♪ Home, home, home
♪ Holidays at home
-Wow, you guys weren't kidding.
No breakfast, no coffee, just... diving right in.
-Who needs caffeine when you can downward dog?
Right? [laughs]
-I got you a water bottle for proper hydration.
-[gasps] Thank you. Hey, Dad,
any chance you're hiding some cookies back there?
-Sorry, sweetie. Your sister runs a tight ship.
-[Chloes sighs] -Okay, enough chitter-chatter.
Family, join me on your mat
and show me your best Christmas tree pose.
-Christmas tree pose? -Yeah.
It's festive. -[Trish and Chloe laugh]
You just do a tree pose like this.
-Mm-hm?
-And then you add some blinking lights.
-[song fades out]
-Got all of her receipts ready.
And there you go. Merry Christmas. [chuckles]
[doorbell chimes ring]
-Hi. -Hi.
-[cheery] Hi. Hey, look at that.
We've finally got a real plumber in the building.
-Well, it's been a while, but I believe
it's like riding a bike. -Hm.
-I can't believe my uniform still fits. [chuckles]
-Thanks for doing this, Clark. -Nice to see you.
And how are you doing, young lady?
-I'm great. So excited to learn how to put the store online.
-I'm very excited to teach you.
-I already started a social media account
for the store, just like you suggested
and it already has a ton of followers.
-Well, there's a lot more we can do to bring traffic there
and increase sales. -Okay, we'll let you two chat.
I'll show your dad the issue with the basement.
-Okay. -Okay.
Clark, follow me.
-You know, my dad really likes spending time with you.
He smiles a lot when you're around.
-I really like spending time with him, too. With both of you.
-Thank you for helping us out, Chloe.
This is like the best Christmas present
you could have ever given us. -It's my pleasure, Alex.
And speaking of Christmas presents,
I have an idea. -Really? What is it?
-Well, I read your short stories last night
and I think they're really good.
-You think so?
-I do. And I think it would be really nice
for your dad to have a copy of all of them.
So, do you remember when I told you my mom helped me
publish my first book and we handed out copies for Christmas?
-Yeah, you sold the rest at a yard sale.
-I think that we should do the same thing for you.
We can send them to my printer.
We can publish them under Angel Wish Publishing
and then you can give 'em to your dad for Christmas.
We can even print extra copies and sell them here
or sell them online.
What do you think?
-I think that's the best idea ever.
-Okay, I'll send you a layout of your book tonight
and you can review it. All you need to do
is come up with a title.
It'll only take a couple days to print,
so you should have it by Christmas Eve.
-Thank you so much, Chloe. He's gonna love it.
-You're very welcome.
Now, should we figure out this online store?
-Let's do it. -Hm.
-[score fades out]
-[gentle score] And just like that,
you are officially open for online business.
-Wow.
I can't believe it's that easy. [scoffs]
I really don't know how to thank you for all of this.
-You don't need to. It's been really good
for me to spend some time with you and Alex.
-It's been great having you here.
Do you think that you could
extend your stay a little while, maybe do some writing from here?
-You know, Trisha asked me the same thing last night.
And to be honest, I'm thinking about it.
-Well, that'd be cool.
Cool?
Am I dating myself? Is cool not cool anymore?
-[Chloe laughs] -Fine. It's fine. I don't know.
I can't tell. -Cool is still cool in my book.
-Okay. Good.
-I, um...
I also talked to my publisher last night.
-Mm. -I told her that
I'm gonna write the novel with or without her support.
So, technically...
there's no reason why I couldn't stick around for a little bit.
-Chloe Anderson, I believe that makes you fearless again.
-Well, I think I'm finding a little bit of strength
from all the support here.
My dad, my sister...
And you.
-Well, we all love having you here.
I love having you here.
Very much.
-I love being here.
Very much.
-You should see their thriller section...
Oh, I'm sorry. Am I interrupting something?
-No, no, not at all. -No. Not at all.
But we should really get going.
I mean, Trisha's gonna be wondering where we are.
And I'm sure she has a very healthy dinner waiting for us.
-Think maybe we could stop for cookies on the way?
-I won't tell if you don't. [soft laugh]
-Thank you so much for everything this afternoon.
Clark, what do I owe you? -Absolutely nothing.
It was just so good to feel needed again.
-Thank you so much. -My pleasure.
Bye, Alex. -See you later, Mr. Anderson.
-Bye. -Bye.
[score fades out]
["Silent Night" on piano]
♪ Silent night Holy night ♪
♪ All is calm All is bright ♪
♪ Round yon virgin Mother and child ♪
♪ Holy infant So tender and mild ♪
♪ Sleep in heavenly peace
♪ Sleep in heavenly peace ♪
- That's always been a favorite Christmas song of mine.
Just a reminder that tickets are still available but going fast
for the Stars Align Christmas Special
coming live to you from New York City.
This event promises to be the best one yet...
-Great title. -...with added musical guests
and promises even more surprises.
After the break, we have more Christmas songs lined up,
including some classics that you probably haven't heard
in quite some time. -[gentle guitar score]
[floorboards creaking]
-Did you decide? -This one?
-This one. -No.
-No.
-This one. -Are you sure?
-I think so.
-Sweetheart, you are way more nervous than me
about this date. I'm the one who's supposed to be nervous.
-I just want it to go well.
And let's be real, Dad, you're a little out of practice.
-How about some encouraging words for
your dear old dad like, "Dad, you'll do great."
-Dad, you'll do great. Just go easy on the dad jokes.
-They're good icebreakers.
-Maybe for a PTA meeting. But for a date,
a good icebreaker is,
"You look beautiful."
-I already used that one.
-What? When?
-When we went ballroom dancing.
-You went ballroom dancing with Chloe Anderson?
-Yeah.
-So, this is more like a second date.
-Well, not really, because ballroom dancing
was sort of a surprise for the both of us, so...
-A second date is so much more pressure.
-It is? -Yes, Dad.
She likes you enough to say yes to a second date,
so that means the dad jokes didn't totally scare her away.
But the bad news is
you probably used up all your good material.
Okay, just calm down and be funny.
-Okay. -But not too funny.
And smile. [exhales]
But with no teeth.
I never thought that I'd be getting dating advice
from my daughter. -Life is full of surprises.
-Sure is. -Now let me see.
-[whisper] Okay.
-Hm. This could work.
-So, thumbs up. -Nobody does that anymore, Dad.
-So, no thumbs and no teeth.
Hm.
-[gentle Christmas-themed score]
-Whoa. [soft laugh] You look pretty tonight.
-Thanks, Dad. -Are you excited?
-It's just a date. [sighs]
Okay, maybe a little nervous. -[Clark and Trish laugh]
-Just have fun, sweetheart. -Thanks.
-[phone ringing] Oh! Mm.
It's Heather.
-CLARK: Mm-hm. -[score fades out]
-Hello? -Hi, honey.
I heard your message and here's the deal:
I want you to push the novel for one year.
-Heather, I made up my mind. I'm not pushing it.
-Give me a moment to explain. -Explain what?
-You know that Christmas special,
that Stars something that airs worldwide
with all those celebrities and artists?
-You mean the Stars Align Christmas Special?
-That's the one.
Well, this year, they want to add an author,
and they want you to read from one of your stories live
on Christmas Eve for all the world to see.
-What? - The caveat is
they want an exclusive to announce your next book
so it looks like you're going to have to give me
another Christmas. -Heather,
I don't even have my next book lined up yet.
-Honey, you've been doing this for years.
Come up with a title and a premise and I'll have
you on a flight to New York by tomorrow night.
-Can I think about it? -Chloe, you can't say no.
This is the greatest opportunity that you'll ever have.
Sleep on it and call me in the morning
with your booking info.
-Okay. -I'm so very proud of you.
-Well? What did she say?
-They want me to read my book on the next
Stars Align Christmas Special.
-TRISH: What? That's huge.
-As long as I announce my next children's book.
-Oh. -And the event is live
on Christmas Eve, so...
I'd have to leave tomorrow. -[Clark sighs]
-Oh.
-Aw, honey, that's okay.
-But I'd miss Christmas.
-Chloe,
you know that we'll support any decision you make.
We're just glad we were able to spend some time with you.
-Thanks, Dad.
Oh, okay. I gotta go. I'm gonna be late.
-Okay, we'll talk when you get back.
-CLARK [whisper]: Yeah. -And... [CLARK/TRISH] have fun!
-Okay. [laughs] I love you.
-[tender score]
Hi.
-Hi.
Wow. You look incredible.
I love your dress.
-Thanks.
I wasn't sure I had the right address.
I thought you were going to cook for me tonight.
I didn't expect a restaurant date.
-Yeah. I, um, I helped the owner with the renovations,
so he owed me a favor.
Got a great kitchen. I love to cook.
-[Chloe chuckles]
They have a beautiful view.
-They sure do.
Um...
Uh, this is for you.
Make yourself comfortable, and, uh, I'll go get dinner.
-Okay. [quiet laugh]
Thank you, Ethan. That was delicious.
-You're very welcome.
-Consider me surprised.
-You mean you didn't predict any of this in any of your
infinite possibilities? Hm?
-I guess I didn't. -Hm.
-But to be fair, I was really trying to be present tonight.
Enjoy the company.
-I'm glad. I really enjoy the company, too.
It's been a long time since I...
felt a connection with someone like this.
-Since Deb?
-Yeah.
-Can you tell me about her?
-No, we don't have to do that. -[overlap] No, I'd...
I'd like to know.
-Okay.
Deb was kind.
She was a dreamer. [laughs]
But she was also really down to earth.
And she loved books.
Like Alex. Uh, she liked being transported
to other worlds, other lifetimes.
I miss her.
I know Alex really misses her, too.
But there is...
There's no benefit in looking back.
[softly] Just hurts too much.
-Ethan, I'm sorry. I didn't mean to--
-No, no, no. That's okay.
It's important that we talk about this.
Especially if you and I are...
I want you in my life, Chloe.
I want you in Alex's life.
Uh, it's the first time since Deb that I've seen her
light up around someone.
You really inspire her.
You spark something in both of us.
-[score fades out]
Did I say something wrong?
-No.
Nothing at all.
Ethan, I have to go. -Chloe!
-Ethan, I want to do this.
I do.
But I can't.
You are kind, and you're wonderful,
and your daughter is incredible.
And she deserves somebody that could be present.
Always.
You both do, and...
I'm...
-Afraid.
-Trying.
But there's so much that can go wrong.
-There's so much that can go right.
-Ethan, my publisher called today with an offer
that I can't turn down.
I'm leaving tomorrow.
-What about Christmas with your family?
-Next year.
I'll still check in on the online store and make sure that
it's running smoothly and I'll stay in touch with Alex.
I will answer any question she has on her writing journey.
I know how important it is to have a mentor at her age.
-Okay.
-Thanks for dinner.
I really did enjoy our time together.
I just... -[softly] No, I...
I understand.
-Can you tell Alex I say goodbye?
-I will.
Goodbye, Chloe.
-Bye, Ethan.
[score fades out]
-You all packed up? -Almost.
I'm sorry, Dad.
I really wanted to be here for Christmas this year.
-Oh, sweetheart,
never apologize for living your life.
Your mother and I raised you to be an independent woman.
To follow your dreams.
I would never fault you for doing something
that you loved.
You gotta follow your heart.
-That's just the thing, Dad.
I'm not sure that this is what my heart wants anymore.
I'm so confused.
I wish somebody could just tell me what to do. [laughs]
-Sweetheart, that's one of the hardest parts of being an adult,
is you gotta make all your decisions for yourself.
-[Chloe sighs, chuckles] -Just know that
we will always be there to support your decisions.
Okay? -Thanks, Dad.
-Oh, do you think you'd have time tomorrow morning to
go for breakfast with your dad? Good cup of coffee
and a gingerbread cookie before you go?
-I would love that.
-I'll see you in the morning then.
Sleep well, sweetheart. I love you.
-I love you, Dad.
Hey, Dad. -Mm-hm?
-Can you tell Trish that I'm gonna be gone for a little bit?
-This time of night?
-There's something that I want to do before I go.
-[church organ playing]
-[organ music fades out] -[tender score]
-[heels clack on wooden stairs]
Merry Christmas, Mom.
I want you to know how much we love you
and miss you.
It's been hard without you.
And I could really use your guidance right now.
I don't know what to do about anything.
About my novel.
The show. [faint sigh]
Christmas.
Ethan.
If you get this message,
do you think you could give me a sign?
A little nudge that I'm on the right track
like you used to.
[rustling]
I know it's not Christmas Eve yet, but
if there's any way you can expedite that message,
I'd really appreciate it. -[score fades out slowly]
-Honey, what are you doing up there?
Do you need a hand?
-I'm sorry. Uh, I'm okay.
I feel so silly.
I was just, um...
-Sending a message.
-[softly] Yeah. -Oh, honey,
there is nothing silly about that at all. [chuckles]
-Oh, Jean.
Whispering a message to an angel on top of a tree
with the hopes that it gets to Heaven.
It's just a kid's story that I made up.
-Chloe,
you have a gift.
Your stories touch people's hearts,
whether you made them up or,
or were inspired by something far greater than us. [chuckles]
Your stories help people understand the world
a little bit better. [soft laugh]
Oh, you mustn't underestimate the power of their truth.
Life can be hard sometimes.
And it can be messy.
But just know you are surrounded by love.
-Thank you, Jean.
I appreciate your kind words. And your hugs.
-And I appreciate you. [chuckles]
And your stories. -[Chloe laughs gently]
-Speaking of which...
I came to thank you.
-For what?
-For all you do for Alex. -[emotional score]
You've inspired that little girl so much. [chuckles]
And printing and sharing her stories. [laughs]
I haven't seen anything so sweet
[laughing] in a long time.
-She told you. -Oh, yeah.
Better yet,
I got the first advanced copy.
-Oh. -[Mrs. Jenkins laughs]
Yeah, they arrived at the bookstore this morning.
When Alex met you,
that was her sign that she was on the right track.
-I guess we're all looking for a sign we're on the right track.
-Oh... And God sends them to us.
We just have to open our eyes to see them.
-Thank you, Jean. I have to go.
-What? I-Is everything okay?
-Yeah.
I just got my sign.
Merry Christmas. -Oh!
Merry Christmas, Chloe.
[keyboard clacking]
[score fades out]
-[quiet conversations] -[plates, cutlery clinking]
-One for you... -[plate clatters]
and one for me.
-You are definitely my daughter. -[tender score]
-Don't tell Trish. -Some days require yoga,
some days require cookies. Life is all about balance.
-Dad, I did a lot of thinking last night
and I have some news.
-You sound serious. What is it, sweetie?
-I'm going to stay for Christmas.
-And what about your Christmas show?
-I gave them full permission to read my book on air
by one of the celebrities already attending.
They loved the idea.
And I also gave them the title of my next book,
Sally's Family Christmas. [chuckles]
-So, you're pushing the novel?
-No.
I did a lot of thinking and so much became clear last night.
I want to write my novel, but I also
want to keep writing children's books.
Just want to do them on my terms.
-And your publisher's okay with this?
-She doesn't have to be.
I decided that I'm going to open my own publishing company.
Angel Wish Publishing. [soft sigh]
I'm going to make it real.
-Chloe, that's wonderful. [laughs]
-It's just going to be a small publishing company at first,
for my own books, but eventually,
I'm going to publish other authors.
I realized that
I don't need Heather to tell me what I can or can't do.
I'm going to follow my heart.
-Oh, sweetheart, I'm so proud of you.
-Thanks, Dad.
-Angel Wish Publishing. Huh.
I only wish your mother was here to see it.
-She is.
-[joyous score]
- Hey, Trish, have you seen my jacket? Trish?
-It's in the kitchen.
-Thank you. -[Trish chuckles]
-A little help, Trish? -I got it, Dad. Follow me.
-I'm so happy that you're staying with us,
Auntie Chloe. -Me too, Jana.
-This is the best Christmas gift ever.
-Aw. -TRISH: I agree with Jana.
This isthe best Christmas gift ever.
-Thank you so much for letting me stay here for a while.
-Our home is your home for as long as you want.
-Now, isn't there some place you need to go
before we head out to Christmas mass?
-There is. -Good luck.
-I love you guys.
-[score ends]
-[doorbell chimes ring]
-[tender score]
Hi.
-Chloe. [soft laugh] I thought you left.
-[Alex exclaims happily] -I decided to stay.
-I'm so happy. Are you coming to the midnight mass?
-I'll be there. -That's awesome.
And you get to meet my grandparents.
Dad, isn't that great?
[whisper] Smile. -[faint sigh]
-[Chloe laughs quietly] -[whisper] Teeth, teeth.
Okay, well, I'll give you guys a minute.
Dad, I'll be in the truck. Merry Christmas, Chloe.
-Merry Christmas, Alex.
-So you decided to stay?
-Mm-hm. -What about your work?
-I made other plans. -Your novel?
-I'm gonna write it.
-That's, uh, really cool.
[both laugh]
Chloe, I-- -Ethan... [measured inhale]
I can imagine an infinite amount of reasons why
I shouldn't be here right now.
But the truth is all of those reasons
are borne out of fear.
I don't want to be scared anymore.
When I'm with you and Alex,
there's only one thing that I feel.
Love.
And that love is powerful.
It makes me believe that I can achieve anything
and I want that.
I want to be brave and fearless.
And I want to take chances.
Stop living in the past and... [measured inhale]
stop worrying about the future.
And I want to live in the present.
I want to see where this story goes.
-[kiss sounds]
-I'm really glad you decided to stay,
Chloe Anderson.
-I'm really glad my name stuck, Ethan.
-Hm. -Merry Christmas.
-Merry Christmas.
♪ Won't you believe in this?
♪ Won't you believe in this?
♪ And the light of lights Gather once again ♪
♪ Won't you believe in this?
♪ And the light of lights Gather once again ♪
♪ Won't you believe in this?
-[song fades out]
-[brass band rendition of "Deck the Halls"]
Can't find what you're looking for?
Get subtitles in any language from opensubtitles.com, and translate them here.